# pipes_vis
A small, interactive GUI/visualizer tool for SPS spectra, powered by Adam Carnall's Bayesian Analysis of Galaxies for Physical Inference and Parameter EStimation (BAGPIPES) <br>

To install, type `pip install pipes_vis`. <br>

Dependencies: bagpipes, numpy, matplotlib, astropy (visualizer still works even if you do not install multinest and pymultinest as instructed by bagpipes' installation) <br>

For requests regarding making the visualizer avaliable as a web interactive tool much like sengi https://www.christopherlovell.co.uk/sengi/, I will have to see how to do it. To be decided in the future.<br>

![alt text](https://github.com/HinLeung622/pipes_vis/blob/main/readme_image.png?raw=true)
